@@ -8,9 +8,6 @@ from os.path import join
 import django
 from django.conf import settings
 
-# Whether Django 1.0 compatibilty mode should be active or not
-DJANGO10_COMPAT = django.VERSION[0] < 1 or (django.VERSION[0] == 1 and django.VERSION[1] < 1)
-
 # ------------------------------------------------------------------------
 # Settings for MediaLibrary
 
@@ -23,18 +20,15 @@ FEINCMS_MEDIALIBRARY_URL = getattr(settings, 'FEINCMS_MEDIALIBRARY_URL', setting
 
 # ------------------------------------------------------------------------
 # Settings for RichText
+FEINCMS_TINYMCE_INIT_TEMPLATE = 'admin/content/richtext/init_tinymce.html'
+FEINCMS_TINYMCE_INIT_CONTEXT  = {
+    'TINYMCE_JS_URL': join(settings.MEDIA_URL, 'js/tiny_mce/tiny_mce.js'),
+    'TINYMCE_CONTENT_CSS_URL': None,
+    'TINYMCE_LINK_LIST_URL': None
+}
 
-TINYMCE_JS_URL = getattr(settings, 'TINYMCE_JS_URL', join(settings.MEDIA_URL, 'js/tiny_mce/tiny_mce.js'))
-
-TINYMCE_CONFIG_URL = getattr(settings, 'TINYMCE_CONFIG_URL', 'admin/content/richtext/init.html')
-
-TINYMCE_CONTENT_CSS_URL = getattr(settings, 'TINYMCE_CONTENT_CSS_URL', None)
-
-TINYMCE_LINK_LIST_URL = getattr(settings, 'TINYMCE_LINK_LIST_URL', None)
-
-CKEDITOR_JS_URL = getattr(settings, 'CKEDITOR_JS_URL', join(settings.MEDIA_URL, 'js/ckeditor/ckeditor.js'))
-
-CKEDITOR_CONFIG_URL = getattr(settings, 'CKEDITOR_CONFIG_URL', 'admin/content/richtext/init_ckeditor.html')
+FEINCMS_RICHTEXT_INIT_TEMPLATE = getattr(settings, 'FEINCMS_RICHTEXT_INIT_TEMPLATE', FEINCMS_TINYMCE_INIT_TEMPLATE)
+FEINCMS_RICHTEXT_INIT_CONTEXT = getattr(settings, 'FEINCMS_RICHTEXT_INIT_CONTEXT', FEINCMS_TINYMCE_INIT_CONTEXT)
 
 # ------------------------------------------------------------------------
 # Admin settings
@@ -42,28 +36,21 @@ CKEDITOR_CONFIG_URL = getattr(settings, 'CKEDITOR_CONFIG_URL', 'admin/content/ri
 FEINCMS_ADMIN_MEDIA = getattr(settings, 'FEINCMS_ADMIN_MEDIA', '/media/sys/feincms/')
 # Link to google APIs instead of using local copy of JS libraries
 FEINCMS_ADMIN_MEDIA_HOTLINKING = getattr(settings, 'FEINCMS_ADMIN_MEDIA_HOTLINKING', False)
+# avoid jQuery conflicts -- scripts should use feincms.jQuery instead of $
+FEINCMS_JQUERY_NO_CONFLICT = \
+    getattr(settings, 'FEINCMS_JQUERY_NO_CONFLICT', False)
 
 # ------------------------------------------------------------------------
 # Settings for the page module
 
-# Use SplitPaneEditor instead of TreeEditor in the page administration
-FEINCMS_PAGE_USE_SPLIT_PANE_EDITOR = getattr(settings, 'FEINCMS_PAGE_USE_SPLIT_PANE_EDITOR', False)
-
 FEINCMS_TREE_EDITOR_INCLUDE_ANCESTORS = getattr(settings, 'FEINCMS_TREE_EDITOR_INCLUDE_ANCESTORS', False)
 
-FEINCMS_ADMIN_TREE_DRAG_AND_DROP = getattr(settings, 'FEINCMS_ADMIN_TREE_DRAG_AND_DROP', True)
-
 # ------------------------------------------------------------------------
 # Enable caching intermediate results in feincms. Be aware that this might deliver
 # slightly out of date pages if you are not using the 'changedate' page extension.
 
 FEINCMS_USE_CACHE = getattr(settings, 'FEINCMS_USE_CACHE', False)
 
-# ------------------------------------------------------------------------
-# Logging class. Defaults to a "do nothing" variant.
-
-FEINCMS_LOGGING_CLASS = getattr(settings, 'FEINCMS_LOGGING_CLASS', 'feincms.logging.LogBase')
-
 # ------------------------------------------------------------------------
 # Allow random gunk after a valid (non appcontent) page?
 
