@@ -36,8 +36,10 @@ def register(cls, admin_cls):
     available_translations_admin.short_description = _('available translations')
     cls.available_translations_admin = available_translations_admin
 
+    if getattr(admin_cls, 'fieldsets'):
+        admin_cls.fieldsets[0][1]['fields'].extend(['language'])
+
     admin_cls.list_display += ('language', 'available_translations_admin')
     admin_cls.list_filter += ('language',)
-    admin_cls.show_on_top += ('language',)
 
     admin_cls.raw_id_fields.append('translation_of')
